@@ -5,7 +5,7 @@
 # jointly copyrighted by participating institutions in DataONE. For
 # more information on DataONE, see our web site at http://dataone.org.
 #
-#   Copyright ${year}
+#   Copyright 2009-2014 DataONE
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -68,8 +68,8 @@ class TestObjectFormatInfo(TestCaseWithURLCompare):
 
 
   def test_200(self):
-    '''mimetype_from_format_id()'''
-    self.assertEqual(self.i.mimetype_from_format_id('netCDF-3'),
+    '''content_type_from_format_id()'''
+    self.assertEqual(self.i.content_type_from_format_id('netCDF-3'),
                                                'application/netcdf')
 
 
